:hide-toc:

.. container:: noclass
   :name: forkongithub

   `Fork on GitHub <https://github.com/kwinkunks/unmap>`_


unmap: data liberation for images
=================================

    | ``unmap`` recovers data from pseudocolour images.


User guide
----------

.. toctree::
    :maxdepth: 2
    :caption: User guide

    readme
    userguide/Unmap_data_from_an_image.ipynb


API reference
-------------

.. toctree::
    :maxdepth: 2
    :caption: API reference

    unmap

* :ref:`genindex`

.. toctree::
    :caption: Project links
    :hidden:

    PyPI releases <https://pypi.org/project/unmap/>
    Code in GitHub <https://github.com/kwinkunks/unmap>
    Issue tracker <https://github.com/kwinkunks/unmap/issues>
    Community guidelines <https://code.agilescientific.com/community>
    More tools <https://code.agilescientific.com>
